==> piwigo-11.5.0.zip: piwigo/language/sv_SE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundinställningar';
$lang['Default gallery language'] = 'Standard språk för galleriet';
$lang['Database configuration'] = 'Databaskonfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Påbörja installation';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det kommer att visas för besökare. Det är nödvändigt för administrering av hemsidan.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ansluten till servern, men kunde inte ansluta till databasen.';
$lang['Can\'t connect to server'] = 'Kan inte ansluta till servern';
$lang['Host'] = 'Värd';
$lang['User'] = 'Användare';
$lang['user login given by your host provider'] = 'användar-inloggning tilldelad av din webbhotells-leverantör';
$lang['user password given by your host provider'] = 'användar-lösenord tilldelad av din webbhotells-leverantör';
$lang['Database name'] = 'Databasnamn';
$lang['also given by your host provider'] = 'också tilldelad av din webbhotell';
$lang['Database table prefix'] = 'Prefix för tabeller i Databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'databastabellernas namn kommer att bli prefixerad med det (detta gör att du kan hantera dina tabeller bättre)';
$lang['enter a login for webmaster'] = 'ange webbadministratörens användarnamn';
$lang['webmaster login can\'t contain characters \' or "'] = 'webb-administratörens inloggning får inte innehålla symbolerna \' eller "';
$lang['please enter your password again'] = 'ange ditt lösenord igen';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Håll det hemligt, lösenordet ger dig tillgång till administrationspanelen';
$lang['Password [confirm]'] = 'Lösenord [bekräfta]';
$lang['verification'] = 'verifiering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Behöver du hjälp? Ställ din fråga på <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besökare kommer att kunna kontakta sidans administratör med denna e-mail adress';
$lang['PHP 5 is required'] = 'PHP 5.2 krävs';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ditt webbhotell använder just nu PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan kanske komma att ändra dina inställningar i PHP 5.2 genom att skapa eller ändra en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notera att du kan ändra dina inställningar förutsatt att du startar om Piwigo efteråt.';
$lang['Try to configure PHP 5'] = 'Försök att konfigurera PHP 5.2';
$lang['Sorry!'] = 'Ursäkta!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kunde inte konfigurera PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi rekomenderar att du kontaktar leverantören för ditt webbhotell för att se hur du kan ändra till PHP 5.2';
$lang['Hope to see you back soon.'] = 'Välkommen tillbaka snart igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerar, Piwigoinstallationen är klar';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ lösning är att kopiera texten ovan och klistra in i filen "local/config/database.inc.php" (Varning: database.inc.php får enbart innehålla texten från textarean, inga radbrytare eller mellanrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kunde inte skapa filen local/config/database.inc.php .';
$lang['Download the config file'] = 'Ladda ner konfigurationsfilen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan ladda ner konfigurationsfilen och sedan ladda upp den till local/config-biblioteket i din installation .';
$lang['Just another Piwigo gallery'] = 'Ännu ett Piwigo galleri';
$lang['Welcome to my photo gallery'] = 'Välkommen till mitt fotogalleri';
$lang['Welcome to your new installation of Piwigo!'] = 'Välkommen till din nya installation av Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Tveka inte att kontakta våra forum för hjälp: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost eller det värdnamn som du tilldelats av ditt webhotells leverantör/server';

==> piwigo-16.1.0.zip: piwigo/language/sv_SE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundinställningar';
$lang['Default gallery language'] = 'Standard språk för galleriet';
$lang['Database configuration'] = 'Databaskonfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Påbörja installation';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det kommer att visas för besökare. Det är nödvändigt för administrering av hemsidan.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ansluten till servern, men kunde inte ansluta till databasen.';
$lang['Can\'t connect to server'] = 'Kan inte ansluta till servern';
$lang['Host'] = 'Värd';
$lang['User'] = 'Användare';
$lang['user login given by your host provider'] = 'användar-inloggning tilldelad av din webbhotells-leverantör';
$lang['user password given by your host provider'] = 'användar-lösenord tilldelad av din webbhotells-leverantör';
$lang['Database name'] = 'Databasnamn';
$lang['also given by your host provider'] = 'också tilldelad av ditt webbhotell';
$lang['Database table prefix'] = 'Prefix för tabeller i Databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'databastabellernas namn kommer att bli prefixerad med det (detta gör att du kan hantera dina tabeller bättre)';
$lang['enter a login for webmaster'] = 'ange webbadministratörens användarnamn';
$lang['webmaster login can\'t contain characters \' or "'] = 'webb-administratörens inloggning får inte innehålla symbolerna \' eller "';
$lang['please enter your password again'] = 'ange ditt lösenord igen';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Håll det hemligt, lösenordet ger dig tillgång till administrationspanelen';
$lang['Password [confirm]'] = 'Lösenord [bekräfta]';
$lang['verification'] = 'verifiering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Behöver du hjälp? Ställ din fråga på <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besökare kommer att kunna kontakta sidans administratör med denna e-mail adress';
$lang['PHP 5 is required'] = 'PHP 5.3 krävs';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ditt webbhotell använder just nu PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan kanske komma att ändra dina inställningar i PHP 5.3 genom att skapa eller ändra en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notera att du kan ändra dina inställningar förutsatt att du startar om Piwigo efteråt.';
$lang['Try to configure PHP 5'] = 'Försök att konfigurera PHP 5.3';
$lang['Sorry!'] = 'Ursäkta!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kunde inte konfigurera PHP 5.3';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi rekomenderar att du kontaktar leverantören för ditt webbhotell för att se hur du kan ändra till PHP 5.3';
$lang['Hope to see you back soon.'] = 'Välkommen tillbaka snart igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerar, Piwigoinstallationen är klar';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ lösning är att kopiera texten ovan och klistra in i filen "local/config/database.inc.php" (Varning: database.inc.php får enbart innehålla texten från textarean, inga radbrytare eller mellanrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kunde inte skapa filen local/config/database.inc.php.';
$lang['Download the config file'] = 'Ladda ner konfigurationsfilen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan ladda ner konfigurationsfilen och sedan ladda upp den till local/config-katalogen i din installation .';
$lang['Just another Piwigo gallery'] = 'Ännu ett Piwigo galleri';
$lang['Welcome to my photo gallery'] = 'Välkommen till mitt fotogalleri';
$lang['Welcome to your new installation of Piwigo!'] = 'Välkommen till din nya installation av Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Tveka inte att kontakta våra forum för hjälp: %s';
$lang['localhost or other, supplied by your host provider'] = 'localhost eller det värdnamn som du tilldelats av ditt webhotells leverantör/server';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP version %s krävs (du kör nu PHP version %s)';
